[pypy-svn] r25336 - pypy/dist/pypy/translator/c/test

tismer at codespeak.net tismer at codespeak.net
Wed Apr 5 07:18:46 CEST 2006


Author: tismer
Date: Wed Apr  5 07:18:44 2006
New Revision: 25336

Modified:
   pypy/dist/pypy/translator/c/test/test_wrapping.py
Log:
weeh. importing twisted works like a charm. going home, need thinking

Modified: pypy/dist/pypy/translator/c/test/test_wrapping.py
==============================================================================
--- pypy/dist/pypy/translator/c/test/test_wrapping.py	(original)
+++ pypy/dist/pypy/translator/c/test/test_wrapping.py	Wed Apr  5 07:18:44 2006
@@ -352,19 +352,17 @@
 # create a space and run geninterp on it?
 # tweak flow space to delay the imports for this func?
 
+### XXX write up the rules how to use this ###
+
 def setup_new_module(mod, modname):
-    # note the name clash with py.test
-    import sys
-    from __builtin__ import type
-    print type(modname)
-    m = type(sys)(modname)
-    print 'hallo', 42
-    dummy = long(42)
+    # note the name clash with py.test on setup_module
+    from types import module
+    m = module(modname)
     allobjs = mod.__dict__.values()
-    funcs = eval('[]')
-    print 'alive'
+    funcs = eval('[]') # or import list from __builtin__
     from twisted.internet import reactor    
     print dir(reactor)
+    #whow this works
     for obj in allobjs:
         print obj, dir(obj)
         if hasattr(42, 'func_name'):



More information about the Pypy-commit mailing list